[PATCH v2 06/10] binman: Add bzip2 bintool

Stefan Herbrechtsmeier stefan.herbrechtsmeier-oss at weidmueller.com
Mon Aug 8 12:51:21 CEST 2022


From: Stefan Herbrechtsmeier <stefan.herbrechtsmeier at weidmueller.com>

Add bzip2 bintool to binman to support on-the-fly compression.

Signed-off-by: Stefan Herbrechtsmeier <stefan.herbrechtsmeier at weidmueller.com>

---

Changes in v2:
- Added

 tools/binman/btool/bzip2.py | 30 ++++++++++++++++++++++++++++++
 tools/binman/comp_util.py   | 14 +++++++-------
 2 files changed, 37 insertions(+), 7 deletions(-)
 create mode 100644 tools/binman/btool/bzip2.py

diff --git a/tools/binman/btool/bzip2.py b/tools/binman/btool/bzip2.py
new file mode 100644
index 0000000000..9be87a621f
--- /dev/null
+++ b/tools/binman/btool/bzip2.py
@@ -0,0 +1,30 @@
+# SPDX-License-Identifier: GPL-2.0+
+# Copyright (C) 2022 Weidmüller Interface GmbH & Co. KG
+# Stefan Herbrechtsmeier <stefan.herbrechtsmeier at weidmueller.com>
+#
+"""Bintool implementation for bzip2
+
+bzip2 allows compression and decompression of files.
+
+Documentation is available via::
+
+   man bzip2
+"""
+
+from binman import bintool
+
+# pylint: disable=C0103
+class Bintoolbzip2(bintool.BintoolPacker):
+    """Compression/decompression using the bzip2 algorithm
+
+    This bintool supports running `bzip2` to compress and decompress data, as
+    used by binman.
+
+    It is also possible to fetch the tool, which uses `apt` to install it.
+
+    Documentation is available via::
+
+        man bzip2
+    """
+    def __init__(self, name):
+        super().__init__(name, version_regex=r'bzip2.*Version ([0-9.]+)')
diff --git a/tools/binman/comp_util.py b/tools/binman/comp_util.py
index faa08a7f8a..fa75911e58 100644
--- a/tools/binman/comp_util.py
+++ b/tools/binman/comp_util.py
@@ -11,7 +11,7 @@ from binman import bintool
 from patman import tools
 
 # Supported compressions
-COMPRESSIONS = ['lz4', 'lzma']
+COMPRESSIONS = ['bzip2', 'lz4', 'lzma']
 
 bintools = {}
 
@@ -34,12 +34,12 @@ def compress(indata, algo):
     Note that for lzma this uses an old version of the algorithm, not that
     provided by xz.
 
-    This requires 'lz4' and 'lzma_alone' tools. It also requires an output
-    directory to be previously set up, by calling PrepareOutputDir().
+    This requires 'bzip2', 'lz4' and 'lzma_alone' tools. It also requires an
+    output directory to be previously set up, by calling PrepareOutputDir().
 
     Args:
         indata (bytes): Input data to compress
         algo (str): Algorithm to use ('none', 'lz4' or 'lzma')
 
     Returns:
         bytes: Compressed data
@@ -60,12 +60,12 @@ def decompress(indata, algo):
     Note that for lzma this uses an old version of the algorithm, not that
     provided by xz.
 
-    This requires 'lz4' and 'lzma_alone' tools. It also requires an output
-    directory to be previously set up, by calling PrepareOutputDir().
+    This requires 'bzip2', 'lz4' and 'lzma_alone' tools. It also requires an
+    output directory to be previously set up, by calling PrepareOutputDir().
 
     Args:
         indata (bytes): Input data to decompress
         algo (str): Algorithm to use ('none', 'lz4' or 'lzma')
 
     Returns:
         (bytes) Compressed data
@@ -34,12 +34,12 @@ def compress(indata, algo):
     Args:
         indata (bytes): Input data to compress
-        algo (str): Algorithm to use ('none', 'lz4' or 'lzma')
+        algo (str): Algorithm to use ('none', 'bzip2', 'lz4' or 'lzma')
 
     Returns:
@@ -60,12 +60,12 @@ def decompress(indata, algo):
     Args:
         indata (bytes): Input data to decompress
-        algo (str): Algorithm to use ('none', 'lz4' or 'lzma')
+        algo (str): Algorithm to use ('none', 'bzip2', 'lz4' or 'lzma')
 
     Returns:
-- 
2.30.2



More information about the U-Boot mailing list